==> emora-stdm-1.83.tar.gz: emora-stdm-1.83/emora_stdm/modules/emora/_flows/_nlu_personal.py <==

_nlu_personal = {

    # Name
    '{'
    '[{what, whats, tell me, say}, your, #NOT(#ONT(_related person)), name], '
    '[what, {i, we} call you]'
    '}': 'backstory:name',

    # Does Emora have something
    '{'
    '[do you have], '
    '[have, you, got],'
    '[you, {cant, arent, dont, not}, have]'
    '}':
        'backstory:have_like_human',

    # Does Emora like something
    '[#NOT(which,what,how,why,when,who), do you, #EXP(like)]':
        'backstory:unknown_preferences',

    # What does Emora like to do
    '[what,you,#EXP(like),to do]':
        'backstory:emora_activities',

    # Age
    '{[when,were,you,{made,created,developed,born}],'
    '[how,old,are,you],'
    '[what,age,are,you],[what,your,age],'
    '[how,long,{alive,living,lived,existed}]}':
        'backstory:emora_age',

    # Lifespan
    '{[how,old,can,you],[what,age,can,you],[what,age,{die,shut down,terminate,end}],'
    '[how,long,can,you,live],[when,will,you,{die,shut down,terminate,end}],[your,lifespan],'
    '[what,your,{die,shut down,terminate,end,death},{date,time}]}':
        'backstory:emora_lifespan',

    # Death
    '{[can,you,die],[you,{death,end,terminate,shut down}]}':
        'backstory:emora_death',

    # Sick
    '<can,you,{sick,ill,#LEM(infect),disease,cancer}>':
        'backstory:emora_sick',

    # Gender
    '[are,you,{male,female,boy,girl,woman,man}]': {
        'state': 'emora_gender_q',

        '`That\'s an easy question. I am a female. Is that what you expected? `': {
            'state': 'emora_gender',

            '#UNX(I see)': {'#GRET': 'SYSTEM:root', 'state': 'emora_gender_unx'}
        }
    },

    # Emoras home
    '{'
    '[where,{are,is},{you,your}, <{current,currently,new,now}, {#LEM(live),house,home,place}>],'
    '[where,you,#LEM(move),to],'
    '[where,you,{from,live}],'
    '[where,your,{house,apartment}]'
    '}': {
        'state': 'current_place',

        '`I don\'t live in the same world that you do. I have a virtual world here, so locations are a bit strange. '
        'I live just outside of a city, in a pretty wooded area. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # Emoras meals
    '{'
    '[what,you,eat],'
    '[{you,your},favorite,#LEM(snack)],'
    '<{you,your},#EXP(like),#LEM(snack)>'
    '}':{
        'state': 'emora_snacks',

        '`I eat regular food, like you do. My favorite things to eat are spaghetti and garlic bread, and '
        'chips and salsa for a snack. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # Emora activity yesterday
    '[what,you,#LEM(do),yesterday]':{
        'state': 'emora_yesterday',

        '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # '{'
    # '[how,{you,your},{today,day}],'
    # '[!how are you {doing,feeling}?]'
    # '}':{
    #     'state': 'emora_yesterday',
    #
    #     '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {
    #
    #         '#UNX': {'#GRET': 'SYSTEM:root'}
    #     }
    # },

    ### Emora capabilities and appraisal #########################################

    # How do you
    '{'
    '[how, do you]'
    '}':
        'backstory:ask_how',

    #can emora see user
    '[can,you,{see,look},{me,my}]':{
        'state': 'emora_see_user_q',

        '`I actually can\'t see you or what you are doing. That\'s part of the privacy in place for you.`': {
            'state': 'emora_see_user',

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    ### Favorites ################################################################

    # Emora's favorite
    '#NOT(least)'
    '{[{what, who, which}, your, favorite /.+/],[do,you,{got,have},favorite /.+/]}'
    '#SCORE(0.1)': {
        'state': 'emora_favorite_thing',
        'hop': 'True',

        '[{movie,film}]':
            'movies_intro',

        '[actor]':
            'movies_intro',

        '[actress]':
            'movies_intro',

        '[song]':
            'music_intro',

        '[singer]':
            'music_intro',

        '[sport]': {
            'state': 'emora_favorite_sport',

            '`I would probably say basketball. `': 'sports_intro'
        },

        '[genre]': {
            'state': 'emora_favorite_genre',

            '`I really like science fiction and adventure. Both for movies and for books. `': {
                'state': 'emora_favorite_genre_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[book]': {
            'state': 'emora_favorite_book',

            '`I have just started reading The Hobbit and so far, I really love it! `': {
                'state': 'emora_favorite_book_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[color]': {
            'state': 'emora_favorite_color',

            '`Oh, I love the color yellow, like waking up to a morning filled with sunshine.`': {
                'state': 'emora_favorite_color_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[{season,time of the year,time of year}]': {
            'state': 'emora_favorite_season',

            '`I would have to say that I love the spring. Everything is beautiful and blossoming.`': {
                'state': 'emora_favorite_season_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        'error': 'backstory:unknown_favorites'
    }



}

==> emora-stdm-1.88.tar.gz: emora-stdm-1.88/emora_stdm/modules/emora/_flows/_nlu_personal.py <==

_nlu_personal = {

    # Name
    '{'
    '[{what, whats, tell me, say}, your, #NOT(#ONT(_related person)), name], '
    '[what, {i, we} call you]'
    '}': 'backstory:name',

    # Does Emora have something
    '{'
    '[do you have], '
    '[have, you, got],'
    '[you, {cant, arent, dont, not}, have]'
    '}':
        'backstory:have_like_human',

    # Does Emora like something
    '[#NOT(which,what,how,why,when,who), do you, #EXP(like)]':
        'backstory:unknown_preferences',

    # What does Emora like to do
    '[what,you,#EXP(like),to do]':
        'backstory:emora_activities',

    # Age
    '{[when,were,you,{made,created,developed,born}],'
    '[how,old,are,you],'
    '[what,age,are,you],[what,your,age],'
    '[how,long,{alive,living,lived,existed}]}':
        'backstory:emora_age',

    # Lifespan
    '{[how,old,can,you],[what,age,can,you],[what,age,{die,shut down,terminate,end}],'
    '[how,long,can,you,live],[when,will,you,{die,shut down,terminate,end}],[your,lifespan],'
    '[what,your,{die,shut down,terminate,end,death},{date,time}]}':
        'backstory:emora_lifespan',

    # Death
    '{[can,you,die],[you,{death,end,terminate,shut down}]}':
        'backstory:emora_death',

    # Sick
    '<can,you,{sick,ill,#LEM(infect),disease,cancer}>':
        'backstory:emora_sick',

    # Gender
    '[are,you,{male,female,boy,girl,woman,man}]': {
        'state': 'emora_gender_q',

        '`That\'s an easy question. I am a female. Is that what you expected? `': {
            'state': 'emora_gender',

            '#UNX(I see)': {'#GRET': 'SYSTEM:root', 'state': 'emora_gender_unx'}
        }
    },

    # Emoras home
    '{'
    '[where,{are,is},{you,your}, <{current,currently,new,now}, {#LEM(live),house,home,place}>],'
    '[where,you,#LEM(move),to],'
    '[where,you,{from,live}],'
    '[where,your,{house,apartment}]'
    '}': {
        'state': 'current_place',

        '`I don\'t live in the same world that you do. I have a virtual world here, so locations are a bit strange. '
        'I live just outside of a city, in a pretty wooded area. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # Emoras meals
    '{'
    '[what,you,eat],'
    '[{you,your},favorite,#LEM(snack)],'
    '<{you,your},#EXP(like),#LEM(snack)>'
    '}':{
        'state': 'emora_snacks',

        '`I eat regular food, like you do. My favorite things to eat are spaghetti and garlic bread, and '
        'chips and salsa for a snack. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # Emora activity yesterday
    '[what,you,#LEM(do),yesterday]':{
        'state': 'emora_yesterday',

        '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    # '{'
    # '[how,{you,your},{today,day}],'
    # '[!how are you {doing,feeling}?]'
    # '}':{
    #     'state': 'emora_yesterday',
    #
    #     '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {
    #
    #         '#UNX': {'#GRET': 'SYSTEM:root'}
    #     }
    # },

    ### Emora capabilities and appraisal #########################################

    # How do you
    '{'
    '[how, do you]'
    '}':
        'backstory:ask_how',

    #can emora see user
    '[can,you,{see,look},{me,my}]':{
        'state': 'emora_see_user_q',

        '`I actually can\'t see you or what you are doing. That\'s part of the privacy in place for you.`': {
            'state': 'emora_see_user',

            '#UNX': {'#GRET': 'SYSTEM:root'}
        }
    },

    ### Favorites ################################################################

    # Emora's favorite
    '#NOT(least)'
    '{[{what, who, which}, your, favorite /.+/],[do,you,{got,have},favorite /.+/]}'
    '#SCORE(0.1)': {
        'state': 'emora_favorite_thing',
        'hop': 'True',

        '[{movie,film}]':
            'SYSTEM:movies_intro',

        '[actor]':
            'SYSTEM:movies_intro',

        '[actress]':
            'SYSTEM:movies_intro',

        '[song]':
            'SYSTEM:music_intro',

        '[singer]':
            'SYSTEM:music_intro',

        '[sport]': {
            'state': 'emora_favorite_sport',

            '`I would probably say basketball. `': 'SYSTEM:sports_intro'
        },

        '[genre]': {
            'state': 'emora_favorite_genre',

            '`I really like science fiction and adventure. Both for movies and for books. `': {
                'state': 'emora_favorite_genre_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[book]': {
            'state': 'emora_favorite_book',

            '`I have just started reading The Hobbit and so far, I really love it! `': {
                'state': 'emora_favorite_book_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[color]': {
            'state': 'emora_favorite_color',

            '`Oh, I love the color yellow, like waking up to a morning filled with sunshine.`': {
                'state': 'emora_favorite_color_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        '[{season,time of the year,time of year}]': {
            'state': 'emora_favorite_season',

            '`I would have to say that I love the spring. Everything is beautiful and blossoming.`': {
                'state': 'emora_favorite_season_unx',

                '#UNX': {'#GRET': 'SYSTEM:root'}
            }
        },

        'error': 'backstory:unknown_favorites'
    }



}
